APP_TIMER_DEF(m_flash_timer_id);        /* LED flash duration timer instance */

static const uint8_t m_qt_led_list[QT_LEDS_NUMBER] = QT_LEDS_LIST;

/* ########## Private functions ########## */

static void flash_timeout_handler(void * p_context)
{
    qt_led_off((uint32_t) p_context);
}

/* ########## Initialisation functions ########## */

void qt_led_init(void)
{
    uint32_t i;
    for (i = 0; i < QT_LEDS_NUMBER; ++i)
    {
        nrf_gpio_cfg_output(m_qt_led_list[i]);
        qt_led_off(i);
    }
    
    ret_code_t err_code = app_timer_create(&m_flash_timer_id, APP_TIMER_MODE_SINGLE_SHOT, flash_timeout_handler);
    APP_ERROR_CHECK(err_code);
}

/* ########## Public utility functions ########## */

void qt_led_on(uint32_t led_idx)
{
    nrf_gpio_pin_write(m_qt_led_list[led_idx], QT_LEDS_ACTIVE_STATE ? 1 : 0);
}

void qt_led_off(uint32_t led_idx)
{
    nrf_gpio_pin_write(m_qt_led_list[led_idx], QT_LEDS_ACTIVE_STATE ? 0 : 1);
}

void qt_led_flash_for_ms(uint32_t led_idx, uint32_t timeout)
{
    ret_code_t err_code = app_timer_start(m_flash_timer_id, APP_TIMER_TICKS(timeout), (void *) led_idx);
    qt_led_on(led_idx);
}
